@@ -53,7 +53,7 @@ typedef struct {
   /** The Atom name length */
   uint8_t name_len;
   /** The Atom name string */
-  char *name;
+  const char *name;
   size_t m_offset;
 } ewmh_atom_t;
 
@@ -740,7 +740,8 @@ xcb_ewmh_request_change_desktop_geometry(xcb_ewmh_connection_t *ewmh,
 {
   const uint32_t data[] = { new_width, new_height };
 
-  return xcb_ewmh_send_client_message(ewmh->connection, XCB_NONE,
+  return xcb_ewmh_send_client_message(ewmh->connection,
+                                      ewmh->screens[screen_nbr]->root,
                                       ewmh->screens[screen_nbr]->root,
                                       ewmh->_NET_DESKTOP_GEOMETRY,
                                       sizeof(data), data);
@@ -791,7 +792,8 @@ xcb_ewmh_request_change_desktop_viewport(xcb_ewmh_connection_t *ewmh,
 {
   const uint32_t data[] = { x, y };
 
-  return xcb_ewmh_send_client_message(ewmh->connection, XCB_NONE,
+  return xcb_ewmh_send_client_message(ewmh->connection,
+                                      ewmh->screens[screen_nbr]->root,
                                       ewmh->screens[screen_nbr]->root,
                                       ewmh->_NET_DESKTOP_VIEWPORT,
                                       sizeof(data), data);
@@ -811,7 +813,8 @@ xcb_ewmh_request_change_current_desktop(xcb_ewmh_connection_t *ewmh,
 {
   const uint32_t data[] = { new_desktop, timestamp };
 
-  return xcb_ewmh_send_client_message(ewmh->connection, XCB_NONE,
+  return xcb_ewmh_send_client_message(ewmh->connection,
+                                      ewmh->screens[screen_nbr]->root,
                                       ewmh->screens[screen_nbr]->root,
                                       ewmh->_NET_CURRENT_DESKTOP,
                                       sizeof(data), data);
@@ -858,8 +861,8 @@ DO_REPLY_LIST_VALUES(workarea, XCB_ATOM_CARDINAL, xcb_ewmh_geometry_t)
  * _NET_SUPPORTING_WM_CHECK
  */
 
-DO_ROOT_SINGLE_VALUE(supporting_wm_check, _NET_SUPPORTING_WM_CHECK,
-                     XCB_ATOM_WINDOW, xcb_window_t)
+DO_SINGLE_VALUE(supporting_wm_check, _NET_SUPPORTING_WM_CHECK,
+                XCB_ATOM_WINDOW, xcb_window_t)
 
 /**
  * _NET_VIRTUAL_ROOTS
